@@ -97,7 +97,7 @@ dtab(tbl) %>% render()
 
 ### Documenting analysis results in Radiant
 
-The report feature in Radiant should be used in conjunction with the <i title='Report results' class='fa fa-edit'></i> icons shown at the bottom of the side bar on (almost) all pages. When that icon is clicked the command used to create the ouput is copied into the editor in the _Report > Rmd_ tab. By default Radiant will paste the code generated for the analysis you just completed at the bottom of the report (i.e., `Auto paste`). However, you can turn off that feature by selecting `Manual paste` from the dropown. With manual paste on, the code is put in the clipboard when you click a report icon and you can paste it where you want in the _Report > Rmd_ editor window.
+The report feature in Radiant should be used in conjunction with the <i title='Report results' class='fa fa-edit'></i> icons shown at the bottom of the side bar on (almost) all pages. When that icon is clicked the command used to create the output is copied into the editor in the _Report > Rmd_ tab. By default Radiant will paste the code generated for the analysis you just completed at the bottom of the report (i.e., `Auto paste`). However, you can turn off that feature by selecting `Manual paste` from the dropown. With manual paste on, the code is put in the clipboard when you click a report icon and you can paste it where you want in the _Report > Rmd_ editor window.
 
 By clicking the `Knit report (Rmd)` button or pressing CTRL-enter (CMD-enter on Mac), the output from the analysis will be (re)created. You can add text, bullets, headers, etc. around the code chunks to describe and explain the results using <a href='https://rmarkdown.rstudio.com/authoring_pandoc_markdown.html' target='_blank'>markdown</a>. You can also select part of the report you want to render.
 
@@ -125,7 +125,7 @@ report_rmd <- reactiveValues(report = 0, knit_button = 0, clear = 0)
 
 output$ui_rmd_generate <- renderUI({
   isolate({
-    init <- ifelse (state_init("r_generate", "Use Rmd") != "Use Rmd", "Use R", "auto")
+    init <- ifelse(state_init("r_generate", "Use Rmd") != "Use Rmd", "Use R", "auto")
   })
   selectInput(
     inputId = "rmd_generate",
@@ -141,7 +141,8 @@ output$ui_rmd_generate <- renderUI({
 output$ui_rmd_view <- renderUI({
   req(input$rmd_generate)
   selectInput(
-    "rmd_view", label = NULL, choices = rmd_view_options,
+    "rmd_view",
+    label = NULL, choices = rmd_view_options,
     selected = state_init("rmd_view", "dual"),
     multiple = FALSE, selectize = FALSE, width = "120px"
   )
@@ -149,7 +150,6 @@ output$ui_rmd_view <- renderUI({
 
 observeEvent(input$rmd_generate, {
   if (isTRUE(input$rmd_generate == "To Rmd")) {
-
     updateSelectInput(session, "rmd_switch", selected = "no_switch")
     updateSelectInput(session, "rmd_view", selected = "pr_only")
     report_rmd$clear <- 1
@@ -177,9 +177,9 @@ observeEvent(input$rmd_generate, {
 
     ## get info from rstudio editor
     cnt <- rstudio_context(type = "rmd")
-    if (radiant.data::is_empty(cnt$path) || cnt$ext != "rmd") {
+    if (is.empty(cnt$path) || cnt$ext != "rmd") {
       rmd <- r_state$radiant_rmd_name
-     if (!radiant.data::is_empty(rmd)) {
+      if (!is.empty(rmd)) {
         if (file.exists(rmd)) {
           ## useful if you are not using an Rstudio project
           rstudioapi::navigateToFile(rmd)
@@ -258,7 +258,7 @@ if (getOption("radiant.shinyFiles", FALSE)) {
   output$ui_rmd_read_files <- renderUI({
     shinyFiles::shinyFilesButton(
       "rmd_read_files", "Read files", "Generate code to read selected file",
-      multiple = FALSE, icon = icon("book"), class = "btn-primary"
+      multiple = FALSE, icon = icon("book", verify_fa = FALSE), class = "btn-primary"
     )
   })
   sf_rmd_read_files <- shinyFiles::shinyFileChoose(
@@ -291,18 +291,20 @@ output$report_rmd <- renderUI({
         td(HTML("&nbsp;&nbsp;")),
         td(
           actionButton(
-            "rmd_knit", " Knit report (Rmd)", icon = icon("play"),
+            "rmd_knit", " Knit report (Rmd)",
+            icon = icon("play", verify_fa = FALSE),
             class = "btn-success"
-          ), class="top_small"
+          ),
+          class = "top_small"
         ),
-        td(uiOutput("ui_rmd_generate"), class="top_small"),
-        td(uiOutput("ui_rmd_view"), class="top_small"),
-        td(uiOutput("ui_rmd_switch"), class="top_small"),
-        td(uiOutput("ui_rmd_save_type"), class="top_small"),
-        td(conditional_save_report("rmd_save"), class="top_small"),
-        td(uiOutput("ui_rmd_load"), class="top_small"),
-        td(conditional_read_files("rmd_read_files"), class="top_small"),
-        td(actionButton("rmd_clear", "Clear output", icon = icon("trash"), class = "btn-danger"), class="top_small")
+        td(uiOutput("ui_rmd_generate"), class = "top_small"),
+        td(uiOutput("ui_rmd_view"), class = "top_small"),
+        td(uiOutput("ui_rmd_switch"), class = "top_small"),
+        td(uiOutput("ui_rmd_save_type"), class = "top_small"),
+        td(conditional_save_report("rmd_save"), class = "top_small"),
+        td(uiOutput("ui_rmd_load"), class = "top_small"),
+        td(conditional_read_files("rmd_read_files"), class = "top_small"),
+        td(actionButton("rmd_clear", "Clear output", icon = icon("trash", verify_fa = FALSE), class = "btn-danger"), class = "top_small")
       )
     ),
     shinyAce::aceEditor(
@@ -389,48 +391,53 @@ rmd_knitted <- eventReactive(report_rmd$report != 1, {
     HTML("<h2>Report was not evaluated. If you have sudo access to the server set options(radiant.report = TRUE) in .Rprofile for the shiny user </h2>")
   } else {
     report <- ""
-    withProgress(message = "Knitting report", value = 1, {
-      if (isTRUE(input$rmd_generate == "To Rmd")) {
-
-        cnt <- rstudio_context(type = "rmd")
-        if (radiant.data::is_empty(cnt$path) || radiant.data::is_empty(cnt$ext, "r")) {
-
-          ## popup to suggest user create an .Rmd file
-          showModal(
-            modalDialog(
-              title = "Report Rstudio (Rmd)",
-              span(
-                "Report is set to use an rmarkdown document in Rstudio
-                ('To Rstudio (Rmd)'). Please check that you have an .Rmd file
-                open in Rstudio and that the file has been saved to disk.
-                If you want to use the editor in Radiant instead, change
-                'To Rstudio (Rmd)' to 'Auto paste' or 'Manual paste'."
-              ),
-              footer = modalButton("OK"),
-              size = "m",
-              easyClose = TRUE
-            )
+    report_type <- "full report"
+    if (isTRUE(input$rmd_generate == "To Rmd")) {
+      cnt <- rstudio_context(type = "rmd")
+      if (is.empty(cnt$path) || is.empty(cnt$ext, "r")) {
+        ## popup to suggest user create an .Rmd file
+        showModal(
+          modalDialog(
+            title = "Report Rstudio (Rmd)",
+            span(
+              "Report is set to use an rmarkdown document in Rstudio
+              ('To Rstudio (Rmd)'). Please check that you have an .Rmd file
+              open in Rstudio and that the file has been saved to disk.
+              If you want to use the editor in Radiant instead, change
+              'To Rstudio (Rmd)' to 'Auto paste' or 'Manual paste'."
+            ),
+            footer = modalButton("OK"),
+            size = "m",
+            easyClose = TRUE
           )
-          report <- ""
+        )
+        report_type <- "nothing"
+        report <- ""
+      } else {
+        if (cnt$path != cnt$rpath) {
+          r_state$radiant_rmd_name <<- cnt$rpath
         } else {
-          if (cnt$path != cnt$rpath) {
-            r_state$radiant_rmd_name <<- cnt$rpath
-          } else {
-            r_state$radiant_rmd_name <<- cnt$path
-          }
-          report <- cnt$content
-        }
-      } else if (!radiant.data::is_empty(input$rmd_edit)) {
-        if (!radiant.data::is_empty(input$rmd_edit_selection, "")) {
-          report <- input$rmd_edit_selection
-        } else if (!radiant.data::is_empty(input$rmd_edit_hotkey$line, "") && report_rmd$knit_button == 0) {
-          report <- input$rmd_edit_hotkey$line
-        } else {
-          report <- input$rmd_edit
-          ## hack to allow processing current line
-          report_rmd$knit_button <- 0
+          r_state$radiant_rmd_name <<- cnt$path
         }
+
+        report_type <- "Rmarkdown file in Rstudio"
+        report <- cnt$content
       }
+    } else if (!is.empty(input$rmd_edit)) {
+      if (!is.empty(input$rmd_edit_selection, "")) {
+        report <- input$rmd_edit_selection
+        report_type <- "report selection"
+      } else if (!is.empty(input$rmd_edit_hotkey$line, "") && report_rmd$knit_button == 0) {
+        report <- input$rmd_edit_hotkey$line
+        report_type <- "report selection"
+      } else {
+        report <- input$rmd_edit
+        ## hack to allow processing current line
+        report_rmd$knit_button <- 0
+      }
+    }
+
+    withProgress(message = glue("Knitting {report_type}"), value = 1, {
       knit_it(report, type = "rmd")
     })
   }
@@ -450,7 +457,12 @@ download_handler(
   label = "Save report",
   fun = function(x, type = "rmd") report_save_content(x, type),
   fn = function() report_save_filename_rmd() %>% sans_ext(),
-  type = function() report_save_filename_rmd() %>% {if (grepl("nb\\.html", .)) "nb.html" else tools::file_ext(.)},
+  type = function() {
+    report_save_filename_rmd() %>%
+      {
+        if (grepl("nb\\.html", .)) "nb.html" else tools::file_ext(.)
+      }
+  },
   caption = "Save report",
   btn = "button",
   class = "btn-primary"
@@ -459,9 +471,13 @@ download_handler(
 observeEvent(input$rmd_load, {
   ## loading report from disk
   if (getOption("radiant.shinyFiles", FALSE)) {
-    if (is.integer(input$rmd_load)) return()
+    if (is.integer(input$rmd_load)) {
+      return()
+    }
     inFile <- shinyFiles::parseFilePaths(sf_volumes, input$rmd_load)
-    if (nrow(inFile) == 0) return()
+    if (nrow(inFile) == 0) {
+      return()
+    }
     path <- inFile$datapath
     pp <- parse_path(path, pdir = getOption("radiant.project_dir", radiant.data::find_home()), chr = "", mess = FALSE)
   } else {
@@ -474,7 +490,7 @@ observeEvent(input$rmd_load, {
     )
   }
 
-  if (!inherits(path, "try-error") && !radiant.data::is_empty(path)) {
+  if (!inherits(path, "try-error") && !is.empty(path)) {
     if (pp$fext == "html") {
       ## based on https://rmarkdown.rstudio.com/r_notebook_format.html
       rmd <- try(rmarkdown::parse_html_notebook(pp$path), silent = TRUE)
@@ -504,14 +520,18 @@ observeEvent(input$rmd_load, {
 })
 
 observeEvent(input$rmd_read_files, {
-  if (is.integer(input$rmd_read_files)) return()
+  if (is.integer(input$rmd_read_files)) {
+    return()
+  }
   path <- shinyFiles::parseFilePaths(sf_volumes, input$rmd_read_files)
-  if (inherits(path, "try-error") || radiant.data::is_empty(path$datapath)) return()
+  if (inherits(path, "try-error") || is.empty(path$datapath)) {
+    return()
+  }
   ldir <- getOption("radiant.launch_dir", default = radiant.data::find_home())
   pdir <- getOption("radiant.project_dir", default = ldir)
 
   cmd <- read_files(path$datapath, pdir = pdir, type = "rmd", clipboard = FALSE, radiant = TRUE)
-  if (!radiant.data::is_empty(cmd)) {
+  if (!is.empty(cmd)) {
     update_report_fun(cmd, type = "rmd", rfiles = TRUE)
   }
 })
